
#
# Trax (network activity tracker) Version 1.3
#
# Copyright 2023 Brandyn Webb
# 
# This file is part of Trax (network activity tracker).
# 
# Trax is free software: you can redistribute it and/or modify it under the terms 
# of the GNU General Public License as published by the Free Software Foundation, 
# either version 3 of the License, or (at your option) any later version.
# 
# Trax is distributed in the hope that it will be useful, but WITHOUT ANY 
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along with 
# Trax. If not, see <https://www.gnu.org/licenses/>. 
# 

"""Various utilities useful for long-running python processes.
"""

import signal

def on_shutdown(func, keyboard=True):
    """This calls func() when this process receives any signals
    that are trying to tell it to die, such as when the operating
    system is shutting down or about to reboot.

    This includes ctrl-C from the terminal (i.e. KeyboardInterrupt)
    unless keyboard is set False.

    func() should be idempotent as it may be called multiple times
        in some circumstances.  It should also do very little and
        then return immediately, as it may be called essentially as
        from another thread.  Generally func() should just set a
        flag, or trigger an event that will later be processed by
        the main dispatch loop. (In trio, setting an Event is suitable.)
    """
    def handler(signum, frame):
        func()

    signal.signal(signal.SIGTERM, handler)
    signal.signal(signal.SIGHUP , handler)
    if keyboard:
        signal.signal(signal.SIGINT, handler)

